==> gd-sprest-0.2.5.tgz: package/src/lib/field.ts <==
/// <reference path="../base.d.ts" />
module $REST {
    /*********************************************************************************************************************************/
    // Field
    // The SPField object.
    /*********************************************************************************************************************************/
    export class Field extends Base {
        /*********************************************************************************************************************************/
        // Constructor
        /*********************************************************************************************************************************/
        constructor(internalNameOrTitle:string, listName?:string, ...args) {
            // Call the base constructor
            super(Base.getInputParmeters.apply(null, args));

            // Query for the field
            return (new Fields(listName, this.targetInfo, false))["getByInternalNameOrTitle"](internalNameOrTitle);
        }
    }

    /*********************************************************************************************************************************/
    // Methods
    /*********************************************************************************************************************************/
    Library.field = {
        // Deletes the object
        delete: {
            requestType: RequestType.Delete
        },

        // Sets the value of the ShowInDisplayForm property for this field.
        setShowInDisplayForm: {
            argNames: ["showInForm"],
            requestType: RequestType.PostWithArgsValueOnly
        },

        // Sets the value of the ShowInEditForm property for this field.
        setShowInEditForm: {
            argNames: ["showInForm"],
            requestType: RequestType.PostWithArgsValueOnly
        },

        // Sets the value of the ShowInNewForm property for this field.
        setShowInNewForm: {
            argNames: ["showInForm"],
            requestType: RequestType.PostWithArgsValueOnly
        },

        // Updates it's properties.
        update: {
            metadataType: "SP.Field",
            name: "",
            requestMethod: "MERGE",
            requestType: RequestType.PostWithArgsInBody
        }
    };
}

==> gd-sprest-0.2.8.tgz: package/src/lib/field.ts <==
/// <reference path="../base.d.ts" />
module $REST {
    /*********************************************************************************************************************************/
    // Field
    // The SPField object.
    /*********************************************************************************************************************************/
    export class Field extends Base {
        /*********************************************************************************************************************************/
        // Constructor
        /*********************************************************************************************************************************/
        constructor(internalNameOrTitle:string, listName?:string, ...args) {
            // Call the base constructor
            super(Base.getInputParmeters.apply(null, args));

            // Get the Fields
            var fields = new Fields(listName, this.targetInfo, false);

            // Query for the field
            return fields["getByInternalNameOrTitle"](internalNameOrTitle);
        }
    }

    export class Field_Async extends Field {
        /*********************************************************************************************************************************/
        // Constructor
        /*********************************************************************************************************************************/
        constructor(internalNameOrTitle:string, listName:string, ...args) {
            // Call the base constructor
            super(internalNameOrTitle, listName, Base.getAsyncInputParmeters.apply(null, args));
        }
    }

    /*********************************************************************************************************************************/
    // Methods
    /*********************************************************************************************************************************/
    Library.field = {
        // Deletes the object
        delete: {
            requestType: RequestType.Delete
        },

        // Sets the value of the ShowInDisplayForm property for this field.
        setShowInDisplayForm: {
            argNames: ["showInForm"],
            requestType: RequestType.PostWithArgsValueOnly
        },

        // Sets the value of the ShowInEditForm property for this field.
        setShowInEditForm: {
            argNames: ["showInForm"],
            requestType: RequestType.PostWithArgsValueOnly
        },

        // Sets the value of the ShowInNewForm property for this field.
        setShowInNewForm: {
            argNames: ["showInForm"],
            requestType: RequestType.PostWithArgsValueOnly
        },

        // Updates it's properties.
        update: {
            metadataType: "SP.Field",
            name: "",
            requestMethod: "MERGE",
            requestType: RequestType.PostWithArgsInBody
        }
    };
}
